@@ -11,7 +11,7 @@ require AutoLoader;
 @EXPORT    = qw();
 @EXPORT_OK = qw( clone );
 
-$VERSION = '0.37';
+$VERSION = '0.39';
 
 bootstrap Clone $VERSION;
 
@@ -22,6 +22,11 @@ __END__
 
 Clone - recursively copy Perl datatypes
 
+=for html
+<a href="https://travis-ci.org/garu/Clone"><img src="https://travis-ci.org/garu/Clone.png?branch=master" alt="Build Status"></a>
+<a href="https://coveralls.io/r/garu/Clone?branch=master"><img src="https://coveralls.io/repos/garu/Clone/badge.png?branch=master" alt="Coverage Status"></a>
+<a href="https://metacpan.org/pod/Clone"><img src="https://badge.fury.io/pl/Clone.svg" alt="CPAN version"></a>
+
 =head1 SYNOPSIS
 
     use Clone 'clone';
@@ -58,7 +63,7 @@ copies of nested hash, array, scalar and reference types,
 including tied variables and objects.
 
 C<clone()> takes a scalar argument and duplicates it. To duplicate lists,
-arrays or hashes, pass them in by reference. e.g.
+arrays or hashes, pass them in by reference, e.g.
 
     my $copy = clone (\@array);
 
@@ -71,12 +76,12 @@ arrays or hashes, pass them in by reference. e.g.
 L<Storable>'s C<dclone()> is a flexible solution for cloning variables,
 albeit slower for average-sized data structures. Simple
 and naive benchmarks show that Clone is faster for data structures
-with 3 or less levels, while C<dclone()> can be faster for structures
+with 3 or fewer levels, while C<dclone()> can be faster for structures
 4 or more levels deep.
 
 =head1 COPYRIGHT
 
-Copyright 2001-2014 Ray Finch. All Rights Reserved.
+Copyright 2001-2017 Ray Finch. All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
